# thenamelisttool

[![Custom CI](https://github.com/UMR-CNRM/thenamelisttool/actions/workflows/lint_test_and_doc.yml/badge.svg)](https://github.com/UMR-CNRM/thenamelisttool/actions/workflows/lint_test_and_doc.yml)
[![Documentation Status](https://readthedocs.org/projects/thenamelisttool/badge/?version=latest)](https://thenamelisttool.readthedocs.io/en/latest/?badge=latest)

The main objectives of this package is to provide command line tools useful to
work with namelists or pack of namelists (update them, compare them, ...).

Originally, it has been developed as part of the *Vortex* project. Recently
the  code has been extracted from the *Vortex* code base. It is now presented
as an independent Python package.
